OC.L10N.register(
    "notes",
    {
    "Notes" : "Poznámky",
    "The last viewed note cannot be accessed. " : "Naposledy prohlížená poznámka nemůže být zpřístupněna. ",
    "The notes folder is not accessible: %s" : "Složka s poznámkami není přístupná: %s",
    "New note" : "Nová poznámka",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Máte neuložené poznámky. Opuštění stránky zahodí všechny změny!",
    "Please wait while new settings are applied…" : "Vyčkejte než se nová nastavení uplatní…",
    "_%n word_::_%n words_" : ["%n slovo","%n slova","%n slov","%n slov"],
    "File error" : "Chyba souboru",
    "Encryption Error" : "Chyba šifrování",
    "Error" : "Chyba",
    "Distraction-free notes and writing" : "Pozornost nerozptylující poznámky a texty",
    "Delete note" : "Smazat poznámku",
    "Favorite" : "Oblíbené",
    "No search result for {{search}}" : "Žádné výsledky hledání pro {{search}}",
    "No notes found" : "Nebyly nalezeny žádné poznámky",
    "Settings" : "Nastavení",
    "Folder to store your notes" : "Složka pro ukládání vašich poznámek",
    "path to notes" : "popis umístění poznámek",
    "File extension for new notes" : "Přípona souboru pro nové poznámky",
    "The note has unsaved changes." : "Poznámka má neuložené změny.",
    "*" : "*",
    "Click here to try again" : "Pro nový pokus klikněte sem",
    "Saving failed!" : "Ukládání se nezdařilo!",
    "Note saved" : "Poznámka uložena"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
